@@ -20,8 +20,9 @@
 import logging
 import re
 from functools import lru_cache
-from urllib.parse import urlparse
 from urllib.parse import unquote
+from urllib.parse import urljoin
+from urllib.parse import urlparse
 from datetime import datetime
 
 from typing import Optional, List, Union, Generator
@@ -47,6 +48,7 @@ LEGACY_URLS = {"https://pypi.python.org/simple": "https://pypi.org/simple"}
 
 def normalize_url(url: str) -> str:
     """We normalize url to remove legacy urls."""
+    url = url.rstrip("/")
     if url in LEGACY_URLS:
         return LEGACY_URLS[url]
     return url
@@ -324,7 +326,7 @@ class Source:
 
             artifact_url = link["href"]
             if not artifact_url.startswith(("http://", "https://")):
-                artifact_url = url + f"/{artifact_name}"
+                artifact_url = urljoin(url, artifact_url)
 
             # Decode characters in link retrieved
             artifact_name = unquote(artifact_name)
@@ -339,10 +341,13 @@ class Source:
         possible_continuations = [".win32", ".tar.gz", ".whl", ".zip", ".exe", ".egg", "-"]
         for artifact_name, artifact_url in self._simple_repository_list_artifacts(package_name):
             # Convert all artifact names to lowercase - as a shortcut we simply convert everything to lowercase.
-            artifact_name.lower()
+            artifact_name = artifact_name.lower()
 
             for i in possible_continuations:
-                if artifact_name.startswith(f"{package_name}-{package_version}{i}"):
+                if (
+                    artifact_name.startswith(f"{package_name}-{package_version}")
+                    or artifact_name.startswith(f"{package_name.replace('-', '_')}-{package_version}")
+                ) and artifact_name.endswith(i):
                     break
             else:
                 _LOGGER.debug(
